# Custom logic

At this point we examined how to change interface appearance, but what about interface logic? Consider following example, you are adding a button and want to show message when button is clicked. To do that, switch to _Properties_ panel and select _OnClick_ event.

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=addevent2.png ':size=300')
</p>

Doing so will create a new event callback and transfer you to the custom interface code editor:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=custominterfacecodeeditor.png ':size=300')
</p>


Events are processed with javascript, and you can put any javascript code inside that field, that code will be executed on every button click. Lets put there something like:

```javascript
alert('Button clicked')
```

You can see, that screen is spitted into four panels: _Html_, _Javascript_, _Css_ and _Preview_. First three panels holds interface source, they reflect all changes made on previous steps and vice versa all changes here will be saved as properties or style settings on main screen. Notice, that changes inside first 3 tabs are immediately visualized on _Preview_ tab. _Preview_ tab shows final interface look, it includes javascript code, html markup and css styles. So, after adding _alert_ function to _OnClick_ event and clicking on that button, proper message will be displayed. You can return to main interface by clicking on _X_ button at right top corner:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=editingcode.gif ':size=300')
</p>


You don't have to add event handler to open code editor again, it is sufficient to click on _Code_ button:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=opencodeeditor.png ':size=300')
</p>


By default javascript panel may use any valid javascript code together with jquery library. Third party libraries may be added, but it will be discussed later. For now, lets write code that sets input field value when button is clicked. To do that first we need assign meaningful id to field which will be changed, because we need to identify element somehow. It could be done from _Html_ panel or from _Id_ setting:


<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=assignidtoelement.png ':size=300')
</p>


Finally, lets add a code, which changes input value:

```javascript
$("#LoginField").val("Code updated")
```

Check jquery documentation for more details about its API.

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=seteditvalue.png ':size=300')
</p>



# Adding custom components

Another interesting library, which is included by default is uikit. It is a framework to build web interfaces. Custom interface uses uikit, so if you will use it too, your changes will look more organic. Lets add uikit's progress bar to our interface. Good place to start will be to look at element [documentation](https://getuikit.com/docs/progress). From there we find out, that element markup is following:

```html
<progress class="uk-progress" value="30" max="100"></progress>
```

Advantage of using html as a foundation for custom interface is that we could just paste that code into _Html_ panel:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=addprogressbartocustominterface.png ':size=300')
</p>

Preview tab is updated immediately, and we see our progress bar now. Another challenge would be to change its value every time the button is clicked. To achieve this we need to replace button click handler with following code:

```javascript
$("#Progress")[0].value += 10
```

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=changeprogressbar.gif ':size=300')
</p>


Third party libraries may be added to custom interface in any amount. As an example, we are going to add moment.js library, it works with dates. Click on _Change_ button inside Javascript panel header to see the list of included *.js files and add moment.js there, its url is following: https://momentjs.com/downloads/moment.js:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=changingtime.gif ':size=300')
</p>

Third party library may also include css or several javascript files.

