# Getting script statistics

There is a list of different methods and events to gather script statistic and information about how script is executed.


## Event _log_

```javascript
if (EventType == "log") {
   var LogType = EventData["type"]
   var LogText = EventData["text"]
   var LogActionId = EventData["action_id"]
}
```

_Log_ event is fired on every new log message. Custom interface is not limited on how it should process it. Log can be appended to text field, shown as notification, or simply ignored. EventData object contains _type_ property with possible values: _user_, _success_, _fail_, _info_. Here is implementation, which uses uikit [notification component](https://getuikit.com/docs/notification):

```javascript
if (EventType == "log") {

  //Convert message type to notification status
  var Status = "primary"
  if(EventData["type"] == "success")
  {
    Status = "success"
  }else if(EventData["type"] == "user")
  {
    Status = "primary"
  }else if(EventData["type"] == "fail")
  {
    Status = "danger"
  }else if(EventData["type"] == "info")
  {
    Status = "warning"
  }
  //Show notification
  UIkit.notification({
      message: EventData["text"],
      status: Status,
      pos: 'bottom-right',
      timeout: 5000
  });
}
```

Result will look like this:


<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=notificationlikes.gif ':size=300')
</p>



## Event _result_

```javascript
if (EventType == "result") {
   var TabNumber = EventData["number"]
}
```

_result_ event is fired when new data is added to following tab:


<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=resulttab2.png ':size=300')
</p>


EventData['number'] value is a tab number. A text, which is added to tab is not present in _EventData_ object, but you can download entire result file with _DownloadResult_ method.


## Event _thread&#95;start_

```javascript
if (EventType == "thread_start") {
   //Code
}
```

Fired after new thread started. Can be used to display number of threads.

## Event _thread&#95;end_

```javascript
if (EventType == "thread_end") {
   var IsSuccess = EventData["success"]
}
```

Fired after new thread finished. Can be used to display number of threads. EventData["success"] contains boolean which equals true only if thread was successful.


## Method _GetScriptReport_

```javascript
Api.GetScriptReport().then((ReportText) => {
    //Code
})
```

_GetScriptReport_ obtains script report text:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=scriptreporttext.png ':size=300')
</p>


This method returns Promise, use _then_ keyword to obtain result.


## Method _GetResourcesReport_

```javascript
Api.GetResourcesReport().then((ReportText) => {
    //Code
})
```

_GetResourcesReport_ obtains resources report text. This method returns Promise, use _then_ keyword to obtain result.

## Method _DownloadLog_

```javascript
Api.DownloadLog().then((LogFileContent) => {
    //Code
})
```

_DownloadLog_ obtains whole log file content. This method returns Promise, use _then_ keyword to obtain result.


## Method _DownloadResult_

```javascript
Api.DownloadResult(Index).then((ResultFileContent) => {
    //Code
})
```

_DownloadResult_ obtains result file content. This method returns Promise, use _then_ keyword to obtain result.