# Inspecting browser

API allows to obtain browser cursor position and browser image.

## Event _browser&#95;add_

```javascript
if (EventType == "browser_add") {
   var BrowserId = EventData["browser_id"]
   var ThreadNumber = EventData["thread_number"]
}
```

Fired after new browser created. Custom interface must preserve browser id to get browser content later.


## Event _browser&#95;remove_

```javascript
if (EventType == "browser_remove") {
   var BrowserId = EventData["browser_id"]
   var ThreadNumber = EventData["thread_number"]
}
```

Fired after browser closed. 


## Event _manual&#95;control&#95;start_

```javascript
if (EventType == "manual_control_start") {
   var BrowserId = EventData["browser_id"]

   /////Open browser instantly, this is optional
   Api.ShowBrowser(BrowserId)
}
```

Fired after script gave control over browser to user. In this mode user can control browser, every mouse movement and keyboard event will be sent to it directly. In order to start controlling browser, you need to execute folowing ```Api.ShowBrowser(BrowserId) ``` code. Right now browser can be controlled manually only by showing native window.

## Event _manual&#95;control&#95;end_

```javascript
if (EventType == "manual_control_end") {
   var BrowserId = EventData["browser_id"]

   /////Close browser instantly, this is optional
   Api.HideBrowser(BrowserId)
}
```

Fired after user have finished manual browser control and pressed following button:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=browserautomationstudio_2019-02-24_13-56-59.png ':size=300')
</p>


After this event is fired, browser can be closed with following code ```Api.HideBrowser(BrowserId) ```. Alternatively, user can close it manually by closing native window.


## Event _show&#95;browser_

```javascript
if (EventType == "show_browser") {
   var BrowserId = EventData["browser_id"]
}
```

Fired after native browser window is shown.


## Event _hide&#95;browser_

```javascript
if (EventType == "hide_browser") {
   var BrowserId = EventData["browser_id"]
}
```

Fired after native browser window is hidden.

## Method _ViewBrowser_

```javascript
Api.ViewBrowser(BrowserId).then((Res)=>{
   var BrowserWidth = Res["width"]
   var BrowserHeight = Res["height"]
   var X = Res["x"]
   var Y = Res["y"]
   var ImageBase64 = Res["image"]
})
```

Execute this method to obtain browser width, height, cursor position and browser screenshot as base64 encoded png image.

_BrowserId_ is a first method parameter, it can be obtained from _browser&#95;add_ event.

If custom interface contains _img_ tag with id BrowserScreen, then it can be updated with browser image with following code:

```javascript
Api.ViewBrowser(BrowserId).then((Res)=>{
   $("#BrowserScreen").attr("src","data:image/png;base64," + Res.image)
})
```

## Method _GetTabs_

```javascript
Api.GetTabs(BrowserId).then((Res)=>{
   var CurrentTabIndex = Res["index"]
   var UrlList = Res["urls"]
})
```

Execute this method to obtain all tabs currently opened in browser.

_BrowserId_ is a first method parameter, it can be obtained from _browser&#95;add_ event.

_urls_ property of returned object contains list of urls, one url for each tab.

_index_ property of returned object contains index of current tab, enumeration starts from 0.

## Method _ShowBrowser_

```javascript
Api.ShowBrowser(BrowserId)
```

Execute this method to show browser native window, this method is required only to control browser directly(to use manual mode), in order to view browser content it is preferable to use _ViewBrowser_ method.


_BrowserId_ is a first method parameter, it can be obtained from _browser&#95;add_ event.


## Method _HideBrowser_

```javascript
Api.HideBrowser(BrowserId)
```

Execute this method to hide browser native window, it will work only if browser is shown with _ShowBrowser_ method before. 

Good place to use this method is _manual&#95;control&#95;end_ event.

_BrowserId_ is a first method parameter, it can be obtained from _browser&#95;add_ event.


## Browser statistic.

In order to enumerate all running browsers, you can use following method:

```javascript
var RunningBrowsers = Api.GetBrowsers()
```

_GetBrowsers_ method will return associative array, which has browser ids as keys and object representing browsers as values. Lets review its content by example.
```javascript
{
	//Browser with id 1
	1:
	{
      "browser_id": 1,
      "task_id": 2, 
	},

	//Browser with id 2
	2:
	{
      "browser_id": 2,
      "task_id": null
	}
}
```

_task&#95;id_ is task identifier, it is generated randomly when task is started. See [calling BAS functions](callbasfunction.md) section for information on how you can use this value. This parameter will be null if browser wasn't started manually with RunFunction method.

_browser&#95;id_ is unique browser identifier, can be used to, for example, show or hide browser.

**Example.** Show all browsers:

```javascript
var RunningBrowsers = Api.GetBrowsers()

//Iterate on all running browsers
Object.keys(RunningBrowsers).forEach(function(BrowserId){
	Api.ShowBrowser(BrowserId)
})
```