# Interacting with native window

This page contains methods to interact with native system window, which shows main interface.


## Method _MoveWindow_


This method moves native window into specified coordinates on the screen.
```javascript
MoveWindow(X, Y)
```

Use following code to move window in (100, 100) coordinates relative to screen upper-left color:

```javascript
MoveWindow(100, 100)
```

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=movewindowwebinterface.gif ':size=300')
</p>

If you want to set initial window position, that is, the position which is set at application start, use web interface settings on [following page](https://bablosoft.com/bas/interface).


## Method _ResizeWindow_


This method resizes native interface window.
```javascript
ResizeWindow(Width, Height)
```

Use following code to set window width to 800 and height to 600:

```javascript
ResizeWindow(800, 600)
```

If you want to set initial window size, that is, the size which is set at application start, use web interface settings on [following page](https://bablosoft.com/bas/interface).



## Method _OpenFileDialog_

With the help of this method you can show the native user dialog to choose file and get result. 


<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=selectfiles.png ':size=300')
</p>

It is available only if you are running interface locally. Automatically generated interface, will handle both(running from local and remote machine) in following way - if interface runs locally, this method will be used to select files, otherwise it will fall back to custom implementation. Custom implementation is not such a familiar to users, but allows to select files remotely:


<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=selectfilescustom.png ':size=300')
</p>


This method accepts hash with several parameters:


```javascript
let Options = 
{
	//Dialog caption, by default it is "Open File" or "Open Directory" depending on your dialog type
		caption: "", 
	
	//If user must select file or directory
		is_dir: false, 
	
	//Starting folder, by default will be set to folder where project residents, will preserve last file location
		dir: "c:/", 

	//Only files that match the given filter are shown. If you want multiple filters, separate them with ';;'.
		filter: "Text files (*.txt);;XML files (*.xml)"
}
Api.OpenFileDialog(Options).then(function(SelectedFile){
	//If user dismiss dialog, SelectedFile will contain empty string
    console.log(SelectedFile)
})
```

You don't need to set all the parameters, default values will bring up open file dialog for any file type: 

```javascript
Api.OpenFileDialog({}).then(function(SelectedFile){
    console.log(SelectedFile)
})
```


## Method _SaveFileDialog_

This method is absolutely the same as [OpenFileDialog](/interactingnativewindow?id=method-openfiledialog), it even has same parameters, but instead of pop up open file dialog, it shows save file dialog:

```javascript
Api.SaveFileDialog({caption: "Where to save data?"}).then(function(SelectedFile){
	//If user dismiss dialog, SelectedFile will contain empty string
    console.log(SelectedFile)
})
```

## Method _ShowNotification_

Use this method to show native notification to user:

```javascript
ShowNotification(Title, Message)
```

It would be displayed near taskbar:

<p align="center">
![](//wiki.bablosoft.com/lib/exe/fetch.php?cache=&media=webinterfacenotification.png ':size=300')
</p>

The alternative way to show notification would be to use javascript code and show message inside window, like this:

```javascript
UIkit.modal.alert(Message)
```


## Method _OpenUrl_

Use this method to open custom url in your default browser. It also can open files of any type in default application.

```javascript
//Open google web site in default browser
OpenUrl("https://google.com")

//Open image in default image viewer
OpenUrl("c:/pic/1.jpg")

//Start notepad
OpenUrl("notepad.exe")

//Use command line arguments
OpenUrl("notepad.exe", "/W c:/path/file.txt")
```

Internally this method will call [ShellExecute](https://docs.microsoft.com/en-us/windows/desktop/api/shellapi/nf-shellapi-shellexecutea) function.

## Method _CloseApplication_

```javascript
CloseApplication()
```

This function immediately stops application and closes window.

