# User authentication

These methods are used during user authentication on login page. 


!> By default all page content is hidden, when page is ready, you can show interface by calling:

```javascript
$("body").fadeIn()
```


## Method _Init_


```javascript
Api.Init(0)
```

This code inits API, it should be called once and only on login page. You should not call this method on main page.


## Event _login_


```javascript
if (EventType == "login") {
    var Username = EventData["username"]
    var Password = EventData["password"]
}
```

Event with type _login_ is fired when BAS expects user to input login and password to authenticate. When event with type _login_ is received, custom interface should display login form. Event has 2 parameters: _username_ and _password_. These are values from previous login, custom interface may set them as default values for current login.



## Method _Login_

```javascript
Api.Login(Username, Password)
```

Authenticate user. _Username_ and _Password_ must be obtained from user input. This method must be call only after _login_ event is received, if you will call it after script started it will do nothing.

!> This method is safe - it encrypts data before sending, if you want to re-implement user authentication, you must protect sensitive data by yourself.

Method returns immediately, if authentication has failed, custom interface will receive event with type _message_. You don't need to process successful authentication, in that case login page will be disposed and main page will be shown automatically.

## Event _message_

```javascript
if (EventType == "message") {
    var MessageText = EventData["text"]
}```

Event with type _message_ is displayed after unsuccessful authentication. Custom interface should display error message and when user finishes reading it, API method _MessageAccepted_ must be call.



## Method _MessageAccepted_

```javascript
Api.MessageAccepted()
```

This method must be called only after _message_ event is received and only after user have read that message.


## Event _show&#95;database&#95;connection_

This event is triggered during database connection, custom interface may show corresponding window. This event has no parameters.


## Event _show&#95;database&#95;log_

```javascript
if (EventType == "show_database_log") {
   var Text = EventData["text"]
}
```

New log message about database connection process. Custom interface may display that message.



## Event _finished&#95;database_

This event is triggered after database connection succeeded. Custom interface may hide database connection window.

## Method _RunWithoutDatabase_

```javascript
Api.RunWithoutDatabase()
```

If database connection takes too long, custom interface may call that method and script will be launched without database.


## Starting embedded languages

Events _show&#95;embedded&#95;connection_, _show&#95;embedded&#95;log_, _finished&#95;embedded_ and method _RunWithoutEmbeddedLanguage_ works exactly in a same way as corresponding entities for database, the only exception is that they are used during embedded language start process.

Check login page default implementation for user authentication API examples.


